/* XPM */
static char * closed_xpm[] = {
"24 24 154 2",
"  	c None",
". 	c #000000",
"+ 	c #828282",
"@ 	c #EEEEEE",
"# 	c #E6E6E6",
"$ 	c #B5B5B5",
"% 	c #949494",
"& 	c #D4D4D4",
"* 	c #E8E8E8",
"= 	c #BCBCBC",
"- 	c #DFDFDF",
"; 	c #A4A4A4",
"> 	c #747474",
", 	c #ADADAD",
"' 	c #EDEDED",
") 	c #E2E2E2",
"! 	c #DCDCDC",
"~ 	c #E5E5E5",
"{ 	c #F7F0E4",
"] 	c #EEDBC3",
"^ 	c #E6CFB2",
"/ 	c #E4CAAD",
"( 	c #E1C8A7",
"_ 	c #DDC3A1",
": 	c #DBC09E",
"< 	c #DCC09E",
"[ 	c #D9BE9A",
"} 	c #D7B994",
"| 	c #D5B28B",
"1 	c #D1AC83",
"2 	c #BF9A71",
"3 	c #F3E1CC",
"4 	c #E4C6A0",
"5 	c #D6AF80",
"6 	c #D3AC7B",
"7 	c #D0A570",
"8 	c #C99F68",
"9 	c #C69B64",
"0 	c #C69C64",
"a 	c #C89D66",
"b 	c #C79C65",
"c 	c #C39860",
"d 	c #C09256",
"e 	c #BC8645",
"f 	c #B67C36",
"g 	c #985E1A",
"h 	c #F1E0CA",
"i 	c #E3C39C",
"j 	c #D3AA7B",
"k 	c #CFA670",
"l 	c #CA9F68",
"m 	c #4B3B26",
"n 	c #4C3C27",
"o 	c #D4B387",
"p 	c #C49961",
"q 	c #C09358",
"r 	c #BC8746",
"s 	c #B77D39",
"t 	c #9A5E1B",
"u 	c #F1E0C9",
"v 	c #E2C29B",
"w 	c #D6AE7F",
"x 	c #D2A97A",
"y 	c #CEA46E",
"z 	c #C89E66",
"A 	c #D6B994",
"B 	c #C2945A",
"C 	c #BE8E50",
"D 	c #BA8442",
"E 	c #B47834",
"F 	c #975C1A",
"G 	c #F2E1CB",
"H 	c #E4C49D",
"I 	c #D7B080",
"J 	c #D4AC79",
"K 	c #CDA570",
"L 	c #4B3A24",
"M 	c #726655",
"N 	c #D6B891",
"O 	c #C19458",
"P 	c #BE8C4E",
"Q 	c #B9813F",
"R 	c #B37834",
"S 	c #975D1A",
"T 	c #F2E0C9",
"U 	c #E0C199",
"V 	c #D3AA7A",
"W 	c #D0A774",
"X 	c #CBA26B",
"Y 	c #C59A62",
"Z 	c #C3975E",
"` 	c #D0AF83",
" .	c #C39861",
"..	c #C09257",
"+.	c #BA833F",
"@.	c #B37934",
"#.	c #9B601E",
"$.	c #E3C29C",
"%.	c #D2AA78",
"&.	c #CDA36C",
"*.	c #775D3A",
"=.	c #85745E",
"-.	c #C19257",
";.	c #BD8C4C",
">.	c #BA813E",
",.	c #B27733",
"'.	c #A36B2F",
").	c #F0DEC7",
"!.	c #E1BD94",
"~.	c #D1A874",
"{.	c #CEA46D",
"].	c #C1935A",
"^.	c #48361F",
"/.	c #483821",
"(.	c #CDA97C",
"_.	c #BE8E51",
":.	c #B67D3A",
"<.	c #B07530",
"[.	c #A67137",
"}.	c #F1E0C8",
"|.	c #E0C099",
"1.	c #D1A973",
"2.	c #BD8C4E",
"3.	c #B9803D",
"4.	c #B67D38",
"5.	c #AB783F",
"6.	c #F1DDC6",
"7.	c #DFC096",
"8.	c #D2A776",
"9.	c #C89D65",
"0.	c #C49960",
"a.	c #CEAC7F",
"b.	c #D8BB96",
"c.	c #D9BF9B",
"d.	c #C9A26F",
"e.	c #C09155",
"f.	c #BC8A4B",
"g.	c #BE8A4C",
"h.	c #A9773C",
"i.	c #DDBF99",
"j.	c #CFA772",
"k.	c #C49256",
"l.	c #C08D51",
"m.	c #BA8849",
"n.	c #B78342",
"o.	c #B48240",
"p.	c #B68241",
"q.	c #B88544",
"r.	c #BB8949",
"s.	c #BC8748",
"t.	c #BA874A",
"u.	c #B98548",
"v.	c #B27B3B",
"w.	c #88521A",
"                                                ",
"                                                ",
"                . . . . . . .                   ",
"              . + @ # # # $ % .                 ",
"            . & * $ = = = - # = .               ",
"          . ; * > . . . . . , # % .             ",
"          . ' % .           . # = .             ",
"          . ) % .           . # = .             ",
"          . ! % .           . ~ = .             ",
"        . . . . . . . . . . . . . . .           ",
"      . { ] ^ / ( _ : : < : [ } | 1 2 .         ",
"      . 3 4 5 6 7 8 9 0 a b c d e f g .         ",
"      . h i 5 j k l m . n o p q r s t .         ",
"      . u v w x y z . . . A B C D E F .         ",
"      . G H I J K z L . M N O P Q R S .         ",
"      . T U V W X Y Z . `  ...P +.@.#..         ",
"      . h $.w %.&.b *.. =.c -.;.>.,.'..         ",
"      . ).!.~.{.0 ].^.. /.(._.r :.<.[..         ",
"      . }.|.j 1.X 9 . . . ` ..2.3.4.5..         ",
"      . 6.7.8.y 9.0.a.b.c.d.e.f.D g.h..         ",
"      . i.j.k.l.m.n.o.p.q.r.s.t.u.v.w..         ",
"        . . . . . . . . . . . . . . .           ",
"                                                ",
"                                                "};

/* XPM */
static char * open_xpm[] = {
"24 24 104 2",
"  	c None",
". 	c #000000",
"+ 	c #828282",
"@ 	c #EEEEEE",
"# 	c #949494",
"$ 	c #D4D4D4",
"% 	c #E8E8E8",
"& 	c #B5B5B5",
"* 	c #E6E6E6",
"= 	c #BCBCBC",
"- 	c #A4A4A4",
"; 	c #747474",
"> 	c #ADADAD",
", 	c #EDEDED",
"' 	c #E2E2E2",
") 	c #DCDCDC",
"! 	c #B4B4B4",
"~ 	c #E6ECF3",
"{ 	c #C9D7E6",
"] 	c #B8CBDF",
"^ 	c #B3C7DC",
"/ 	c #AEC3D9",
"( 	c #A7BED6",
"_ 	c #A3BBD4",
": 	c #A4BCD5",
"< 	c #9EB8D3",
"[ 	c #99B4D0",
"} 	c #92AFCD",
"| 	c #8AA9C9",
"1 	c #7197BE",
"2 	c #D3DEEA",
"3 	c #ABC1D8",
"4 	c #8BAACA",
"5 	c #86A6C7",
"6 	c #7C9FC3",
"7 	c #6D94BC",
"8 	c #7096BD",
"9 	c #6E95BD",
"0 	c #6890B9",
"a 	c #5F8AB6",
"b 	c #507FAF",
"c 	c #4A75A1",
"d 	c #37587A",
"e 	c #D0DCE9",
"f 	c #7B9EC2",
"g 	c #7398BF",
"h 	c #23374C",
"i 	c #23384E",
"j 	c #8EACCB",
"k 	c #6991BA",
"l 	c #618BB6",
"m 	c #5280AF",
"n 	c #4B77A4",
"o 	c #38597B",
"p 	c #A5BDD6",
"q 	c #84A5C7",
"r 	c #799DC2",
"s 	c #638DB8",
"t 	c #5A86B3",
"u 	c #4F7DAC",
"v 	c #48739F",
"w 	c #375778",
"x 	c #D1DDEA",
"y 	c #A8BFD7",
"z 	c #22364B",
"A 	c #3E6287",
"B 	c #96B2CF",
"C 	c #5885B3",
"D 	c #4D7BAA",
"E 	c #48729D",
"F 	c #7FA1C4",
"G 	c #759AC0",
"H 	c #6A92BB",
"I 	c #668FB9",
"J 	c #88A8C9",
"K 	c #395B7E",
"L 	c #83A4C6",
"M 	c #779BC0",
"N 	c #46709B",
"O 	c #5683B1",
"P 	c #47719C",
"Q 	c #416890",
"R 	c #CDDAE8",
"S 	c #A0B9D3",
"T 	c #789CC1",
"U 	c #628CB7",
"V 	c #1F3246",
"W 	c #203347",
"X 	c #82A3C5",
"Y 	c #466F99",
"Z 	c #456D96",
"` 	c #CEDBE9",
" .	c #5784B2",
"..	c #4D7AA8",
"+.	c #4A76A3",
"@.	c #4974A0",
"#.	c #9CB6D1",
"$.	c #5E89B5",
"%.	c #5482B1",
"&.	c #A1BAD4",
"*.	c #5B87B4",
"=.	c #4C79A7",
"-.	c #5381B0",
";.	c #32506F",
"                                                ",
"                              . . . . . .       ",
"                            . + @ @ @ @ # .     ",
"                          . $ % & & & & * = .   ",
"                        . - % ; . . . . > * # . ",
"                        . , # .         . * = . ",
"                        . ' # .         . * = . ",
"                        . ' # .         . * = . ",
"                        . ) # .         . * = . ",
"    . . . . . . . . . . . . . . .       . ! ; . ",
"  . ~ { ] ^ / ( _ _ : _ < [ } | 1 .       . .   ",
"  . 2 3 4 5 6 1 7 7 8 9 0 a b c d .             ",
"  . e ( 4 5 f g h . i j k l m n o .             ",
"  . e p | q r 8 . . . [ s t u v w .             ",
"  . x y 4 q r 8 z . A B l C D E w .             ",
"  . e _ q F G H I . J k a C D E K .             ",
"  . e ( | L M 9 w . N 0 l O D P Q .             ",
"  . R S F T 7 U V . W X t m n Y Z .             ",
"  . ` _ 5 F G 7 . . . J a  ...+.@..             ",
"  . R S X r 9 k q #.S M $.%.u  .P .             ",
"  . &.6 U *.m D =...u -.-.-.b c ;..             ",
"    . . . . . . . . . . . . . . .               ",
"                                                ",
"                                                "};


/* XPM */
static char * rest_xpm[] = {
"24 24 30 1",
" 	c None",
".	c #1593A5",
"+	c #7CC3CE",
"@	c #F7FBFC",
"#	c #A8D7DF",
"$	c #47AAB9",
"%	c #EEF7F9",
"&	c #4FADBC",
"*	c #40A6B6",
"=	c #078C9F",
"-	c #9FD3DB",
";	c #39A3B3",
">	c #0E90A2",
",	c #C2E3E8",
"'	c #B0DBE2",
")	c #6BBBC7",
"!	c #85C7D2",
"~	c #2B9DAE",
"{	c #64B8C4",
"]	c #8DCBD5",
"^	c #D4EBEF",
"/	c #32A0B0",
"(	c #DCEFF2",
"_	c #00889E",
":	c #96CFD8",
"<	c #B9DFE5",
"[	c #56B0BF",
"}	c #1C96A8",
"|	c #FFFFFF",
"1	c #73BFCB",
"____.}}}}}}}}}}}}}}}=___",
"__}{11111111111111111*=_",
"_.1111<1:1-11111#]1111&_",
"_[1111<1<1,1111-|:11111}",
">11111(1(1(1111%|:11111$",
"}11111|1(!(111+||:11111[",
"}11111|+@:@111:||:11111[",
"}11111||||@1111||:11111[",
"}11111#|||:1111||:11111[",
"}111111<|<11111%|:11111[",
"}111111<|<11111(|:11111[",
"}111111<|<11111(|:11111[",
"}111111<|<11111(|:11111[",
"}111111<|<11111(|:11111[",
"}111111<|<11111(|:11111[",
"}111111<|<11111(|:11111[",
"}111111<|<11111(|:11111[",
"}111111<|<11111(|:11111[",
"}111111<|<11111(|:11111[",
".111111<|<11111(|:11111[",
"_)11111<|<11111(|:11111&",
"_/11111<|<11111^|:11111~",
"__*1111+#111111+'11111$_",
"___.;[[[[[[[[[[[[[[$;.__"};


/* XPM */
static char * mcdonalds_xpm[] = {
"24 24 74 1",
" 	c None",
".	c #FFFFFF",
"+	c #FFFF99",
"@	c #FFFF66",
"#	c #FFFF33",
"$	c #FFFF00",
"%	c #FFCCCC",
"&	c #FFCC99",
"*	c #FFCC66",
"=	c #FFCC33",
"-	c #FFCC00",
";	c #FF9933",
">	c #CCCCCC",
",	c #CCCC00",
"'	c #CC9999",
")	c #CC9933",
"!	c #CC9900",
"~	c #CC6666",
"{	c #CC6600",
"]	c #CC3333",
"^	c #CC3300",
"/	c #999900",
"(	c #996633",
"_	c #996600",
":	c #993300",
"<	c #990000",
"[	c #666633",
"}	c #666600",
"|	c #663333",
"1	c #663300",
"2	c #660033",
"3	c #660000",
"4	c #333333",
"5	c #330033",
"6	c #330000",
"7	c #C0C0C0",
"8	c #A91718",
"9	c #B70A13",
"0	c #910814",
"a	c #A30119",
"b	c #FCFCF8",
"c	c #F8ED02",
"d	c #A89B0C",
"e	c #F1D205",
"f	c #CEB605",
"g	c #F9E229",
"h	c #FBE653",
"i	c #836F15",
"j	c #774427",
"k	c #F9F0ED",
"l	c #AE2100",
"m	c #D04B30",
"n	c #C42D13",
"o	c #CA3921",
"p	c #DE8171",
"q	c #F6DCD7",
"r	c #C81C01",
"s	c #8D1301",
"t	c #D55A47",
"u	c #EFBEB6",
"v	c #C91600",
"w	c #C61600",
"x	c #A71401",
"y	c #B71503",
"z	c #BE210F",
"A	c #55211B",
"B	c #E59D94",
"C	c #7E1D17",
"D	c #B50802",
"E	c #C11E17",
"F	c #A70301",
"G	c #810503",
"H	c #942121",
"I	c #A53232",
"                        ",
"       rCdi   rC,|      ",
"       Aeege  /hee}     ",
"      xcef$exxgeAgc     ",
"     xAhcGA=djhcGdej    ",
"     xceAsGhecefsChc    ",
"    Ds@eDxGge+ejxGgeC   ",
"    x|@cyDsc=&cCxsegd   ",
"    xfg,yysfh@cyys}hcy  ",
"    seedwxs/@hewys5&c0  ",
"   ys@ejw sA+g,vys3@ej  ",
"   xs@e0wys4@eiv xChef  ",
"  rx3&e wysAhe}wwxG@ec  ",
"  sp~+e~ppp~@epppp~heepI",
" x|l:+essssxgc^^^^mgeem3",
" sAsGeeGGGDyD9yzznngecmA",
" xGa0p~GGt~DGssyspxmxzuC",
" xs0:u%bDuGBG%bFbqFtqtm ",
" xs6e<<G<D<Dyzzxyomotzor",
" ls4@FFFFFDDyyyzznnoooy ",
" lsC9FFFDDDDyyyyzEnnoo< ",
"  ssAAAAAAAAAAAAAAAAAAC ",
"  lxxxxxxxx:xxxxxxxxxl  ",
"                        "};


/* XPM */
static char * burgerking_xpm[] = {
"24 24 333 2",
"  	c None",
". 	c #84A3C5",
"+ 	c #AEC3D9",
"@ 	c #C4D1DD",
"# 	c #D6DCDF",
"$ 	c #E1E2E1",
"% 	c #EAEDEE",
"& 	c #F5F7FA",
"* 	c #38659D",
"= 	c #8DA8C8",
"- 	c #EBEBE8",
"; 	c #FFDFA9",
"> 	c #FFC35C",
", 	c #FFB12B",
"' 	c #FFAF23",
") 	c #FEBA44",
"! 	c #FECF7D",
"~ 	c #FFD58D",
"{ 	c #FFEFD3",
"] 	c #FFFFFE",
"^ 	c #4773A6",
"/ 	c #DAE2ED",
"( 	c #FEEAC6",
"_ 	c #FEC155",
": 	c #FFA405",
"< 	c #FFA302",
"[ 	c #FFA70F",
"} 	c #FEE3B5",
"| 	c #FFAC1F",
"1 	c #FFDCA1",
"2 	c #FFFFFF",
"3 	c #4671A5",
"4 	c #E6ECF3",
"5 	c #FEE4B5",
"6 	c #FEC665",
"7 	c #FFA202",
"8 	c #FFA813",
"9 	c #FEBC48",
"0 	c #FED48B",
"a 	c #FEDB9E",
"b 	c #FDE8CF",
"c 	c #F8CCCE",
"d 	c #F6BBBE",
"e 	c #FDF2F3",
"f 	c #2E609A",
"g 	c #DCE4EE",
"h 	c #FFF8EC",
"i 	c #FECB73",
"j 	c #FFAD1E",
"k 	c #FFA70D",
"l 	c #FFB940",
"m 	c #FFCF7D",
"n 	c #FEE8C3",
"o 	c #F8C9C3",
"p 	c #F7C2C4",
"q 	c #F19599",
"r 	c #E7444B",
"s 	c #EC747A",
"t 	c #E42229",
"u 	c #E62F37",
"v 	c #F4ACAF",
"w 	c #38679F",
"x 	c #91ABCA",
"y 	c #FFD896",
"z 	c #FEB73E",
"A 	c #FFBF52",
"B 	c #FEDDA6",
"C 	c #FCE4DB",
"D 	c #F4ABAE",
"E 	c #F8C7C9",
"F 	c #EF8085",
"G 	c #E52A33",
"H 	c #EC686E",
"I 	c #E84D55",
"J 	c #E95259",
"K 	c #F09498",
"L 	c #E31C24",
"M 	c #E52630",
"N 	c #FADCDD",
"O 	c #2F609B",
"P 	c #F1F4F8",
"Q 	c #FEF4E1",
"R 	c #FBDAD0",
"S 	c #FBE5E6",
"T 	c #EB6168",
"U 	c #E7434B",
"V 	c #EA5D63",
"W 	c #E52F38",
"X 	c #E31D25",
"Y 	c #F19296",
"Z 	c #E74047",
"` 	c #E73E46",
" .	c #ED6F75",
"..	c #F3A8AB",
"+.	c #E53339",
"@.	c #E8454C",
"#.	c #F29B9F",
"$.	c #5980AF",
"%.	c #6E91B9",
"&.	c #FCEDEE",
"*.	c #F3A3A7",
"=.	c #F3A2A5",
"-.	c #E6363E",
";.	c #F3A5A8",
">.	c #E4222C",
",.	c #E63D45",
"'.	c #E6353E",
").	c #EE7A80",
"!.	c #E4252D",
"~.	c #EF7F84",
"{.	c #E52E36",
"].	c #F09194",
"^.	c #ED7277",
"/.	c #F0888C",
"(.	c #FDF4F5",
"_.	c #3668A0",
":.	c #B0C4DA",
"<.	c #ED6B70",
"[.	c #EA5B62",
"}.	c #E6343D",
"|.	c #F2A0A4",
"1.	c #E4222B",
"2.	c #E52D35",
"3.	c #F7C3C5",
"4.	c #EE747A",
"5.	c #F4ACB0",
"6.	c #F08F93",
"7.	c #FADADC",
"8.	c #EB6066",
"9.	c #E20A15",
"0.	c #E42029",
"a.	c #E31C25",
"b.	c #F7C8CA",
"c.	c #194F90",
"d.	c #D1DCE9",
"e.	c #EC646B",
"f.	c #E6343E",
"g.	c #E62F39",
"h.	c #E5313B",
"i.	c #E94B53",
"j.	c #E83D46",
"k.	c #F08C8F",
"l.	c #F8CED0",
"m.	c #F3A7AA",
"n.	c #EB5F66",
"o.	c #FAD9DA",
"p.	c #F5B5B7",
"q.	c #E20711",
"r.	c #EE7C82",
"s.	c #E20713",
"t.	c #EE7D82",
"u.	c #F8CDCF",
"v.	c #0B468A",
"w.	c #D7E2EC",
"x.	c #EC636A",
"y.	c #EC666D",
"z.	c #E4202A",
"A.	c #F6BABD",
"B.	c #EF7F85",
"C.	c #F8C8CA",
"D.	c #E4282F",
"E.	c #EB6067",
"F.	c #E20814",
"G.	c #E52933",
"H.	c #F09195",
"I.	c #E95158",
"J.	c #E1050F",
"K.	c #F6C2C5",
"L.	c #E3141E",
"M.	c #F5B8BB",
"N.	c #0A458A",
"O.	c #D2DDE9",
"P.	c #EE7379",
"Q.	c #EB6369",
"R.	c #F3A6A9",
"S.	c #E6333C",
"T.	c #E8444B",
"U.	c #E7333C",
"V.	c #E42128",
"W.	c #EB6068",
"X.	c #E20A16",
"Y.	c #E20B16",
"Z.	c #E3111D",
"`.	c #EA5E65",
" +	c #EF8086",
".+	c #F08A8F",
"++	c #F6BFC2",
"@+	c #154E8F",
"#+	c #B3C5DB",
"$+	c #FEFBFB",
"%+	c #E9545B",
"&+	c #E4212B",
"*+	c #F0898E",
"=+	c #F5B2B5",
"-+	c #E7333D",
";+	c #E31521",
">+	c #EE7E83",
",+	c #F5B0B4",
"'+	c #E6313A",
")+	c #E20C18",
"!+	c #E2111B",
"~+	c #EB6268",
"{+	c #FEF6F6",
"]+	c #3C6CA2",
"^+	c #7597BD",
"/+	c #E73B44",
"(+	c #E3131F",
"_+	c #E3131E",
":+	c #EA535A",
"<+	c #E6323C",
"[+	c #E31520",
"}+	c #FCEEEF",
"|+	c #EE7B80",
"1+	c #E52730",
"2+	c #FBE2E2",
"3+	c #FDEDE0",
"4+	c #FABF95",
"5+	c #FAC594",
"6+	c #FFFDFD",
"7+	c #F7CACC",
"8+	c #F7C9CB",
"9+	c #6B8FB8",
"0+	c #235896",
"a+	c #F0F4F8",
"b+	c #E20F1B",
"c+	c #E30F1B",
"d+	c #E41B26",
"e+	c #F6B9BC",
"f+	c #E6333D",
"g+	c #E4252E",
"h+	c #EC6A70",
"i+	c #EC646A",
"j+	c #FEFAF6",
"k+	c #FEE9C7",
"l+	c #FDC578",
"m+	c #FFBA45",
"n+	c #FFAA19",
"o+	c #FFC054",
"p+	c #FED58F",
"q+	c #A4B9D3",
"r+	c #B8AFC3",
"s+	c #F8DFE0",
"t+	c #0E498C",
"u+	c #8EA9C9",
"v+	c #F3A4A8",
"w+	c #E20E19",
"x+	c #E73840",
"y+	c #EB6269",
"z+	c #F4AAAA",
"A+	c #FDDFBB",
"B+	c #FECB76",
"C+	c #FFB029",
"D+	c #FFA407",
"E+	c #FFC664",
"F+	c #FEC96D",
"G+	c #E7E8E6",
"H+	c #1D5594",
"I+	c #054288",
"J+	c #99B2CF",
"K+	c #507AAB",
"L+	c #185091",
"M+	c #D8313E",
"N+	c #E42730",
"O+	c #F9C7B5",
"P+	c #FECD7C",
"Q+	c #FFAE22",
"R+	c #FFA305",
"S+	c #FFB332",
"T+	c #FECA6E",
"U+	c #FCEDD1",
"V+	c #5780AF",
"W+	c #004087",
"X+	c #195292",
"Y+	c #33639C",
"Z+	c #B66479",
"`+	c #D5B3BE",
" @	c #FFF1D8",
".@	c #FFA815",
"+@	c #FEAC1E",
"@@	c #FECF7E",
"#@	c #FDF4E4",
"$@	c #7799BF",
"%@	c #074589",
"&@	c #82A2C4",
"*@	c #A4BBD3",
"=@	c #175090",
"-@	c #185191",
";@	c #A8BDD5",
">@	c #F8FAFC",
",@	c #FFF3DF",
"'@	c #FFD48C",
")@	c #FFC157",
"!@	c #FFB73E",
"~@	c #FFC259",
"{@	c #FFD388",
"]@	c #FFF0D5",
"^@	c #E7EDF3",
"/@	c #5F86B3",
"(@	c #044288",
"_@	c #6C8FB9",
":@	c #95AFCC",
"<@	c #1D5593",
"[@	c #014187",
"}@	c #396AA1",
"|@	c #A2B9D3",
"1@	c #DDE6EF",
"2@	c #FCFDFD",
"3@	c #FCFDFE",
"4@	c #D9E3ED",
"5@	c #8AA7C7",
"6@	c #1E5694",
"7@	c #004187",
"8@	c #0A478B",
"9@	c #668BB6",
"0@	c #4773A7",
"a@	c #07458A",
"b@	c #004086",
"c@	c #09468A",
"d@	c #1A5393",
"e@	c #2A609B",
"f@	c #2A609A",
"g@	c #08458A",
"h@	c #014087",
"i@	c #2C609B",
"j@	c #8DAAC9",
"k@	c #5A82B0",
"l@	c #31649D",
"m@	c #0F4A8D",
"n@	c #014288",
"o@	c #09478A",
"p@	c #255A97",
"q@	c #4C78AA",
"r@	c #7496BC",
"                                                ",
"                  . + @ # $ % &                 ",
"            * = - ; > , ' ) ! ~ { ]             ",
"          ^ / ( _ : < < < < [ } | 1 2           ",
"        3 4 5 6 : < < < 7 8 9 0 a b c d e       ",
"      f g h i j < k l m n o p q r s t u v       ",
"    w x 2 y z A B C D E F G H I J K L M N 2     ",
"    O P 2 Q R S T U V W X Y Z `  ...+.@.#.2 2   ",
"  $.%.&.*.=.-.;.>.,.'.).!.~.{.J @.].^./.Y (.2   ",
"  _.:.<.[.{.}.|.1.,.^.2.3.4.5.6.7.8.9.0.a.b.2   ",
"  c.d.e.f.g.h.i.j.k.l.m.n.o.p.q.r.s.t.u.q o.2 2 ",
"  v.w.x.y.z.A.B.C.^.D.E.F.G.H.q.I.J.K.L.s.M.2 2 ",
"  N.O.P.Q.R.(.S.T.U.V.W.X.Y.Z.F.`.s. +.+s.++2 2 ",
"  @+#+$+%+&+*+Y.=+-+V.W.;+>+9.F.,+'+)+!+~+{+2 2 ",
"  ]+^+2 /+(+_+:+$+<+V.W.[+}+|+1+2+3+4+5+6+7+8+  ",
"  9+0+a+/+b+c+d+e+f+g+h+i+j+k+l+m+n+o+p+q+r+s+  ",
"    t+u+/+&+v+w+x+y+z+A+B+C+D+< < E+F+G+H+I+J+  ",
"    K+L+M+N+] C.O+P+Q+R+< < < < S+T+U+V+W+X+    ",
"      Y+Z+`+2  @.@< < < < < < +@@@#@$@W+%@&@    ",
"      *@=@-@;@>@,@'@)@!@!@~@{@]@^@/@W+(@_@      ",
"        :@<@[@}@|@1@P 2@3@P 4@5@6@7@8@9@        ",
"            0@a@b@c@d@e@f@d@g@W+h@i@j@          ",
"                k@l@m@n@7@o@p@q@r@              ",
"                                                "};


/* XPM */
static char * shop_xpm[] = {
"24 24 293 2",
"  	c None",
". 	c #B3B4B8",
"+ 	c #E3E6E9",
"@ 	c #D4D9E2",
"# 	c #9FA1A5",
"$ 	c #9B9C9E",
"% 	c #C2C3C5",
"& 	c #D1D4DB",
"* 	c #CAD4E7",
"= 	c #B2BEDB",
"- 	c #C2CEE7",
"; 	c #8898B9",
"> 	c #F1FFFF",
", 	c #ABB8CA",
"' 	c #798399",
") 	c #BEBFC4",
"! 	c #E1E7F1",
"~ 	c #C6CEE0",
"{ 	c #D3DBEA",
"] 	c #ABBAD8",
"^ 	c #A2B1D4",
"/ 	c #A3B5DE",
"( 	c #535B72",
"_ 	c #CCD5E5",
": 	c #AEB3BD",
"< 	c #B9BFCA",
"[ 	c #E8F0FA",
"} 	c #778093",
"| 	c #3F4149",
"1 	c #545454",
"2 	c #636363",
"3 	c #BCC0C6",
"4 	c #B7C2D9",
"5 	c #A1B0CE",
"6 	c #A9B8DB",
"7 	c #7F8AA5",
"8 	c #A6B4D1",
"9 	c #90A1CA",
"0 	c #4F566B",
"a 	c #BBC5DA",
"b 	c #B8C0D2",
"c 	c #BAC2D0",
"d 	c #A3B1D0",
"e 	c #D5DAE3",
"f 	c #7E88A1",
"g 	c #4B4E59",
"h 	c #494848",
"i 	c #595959",
"j 	c #C2C5CB",
"k 	c #ACB5CA",
"l 	c #A9B3C9",
"m 	c #A7B3CE",
"n 	c #B4B8BF",
"o 	c #D7DADE",
"p 	c #C2C7D3",
"q 	c #7E8493",
"r 	c #A9B4C9",
"s 	c #AAB4CB",
"t 	c #AFBACE",
"u 	c #8B94AA",
"v 	c #818285",
"w 	c #8E9CB7",
"x 	c #5D667F",
"y 	c #35363C",
"z 	c #4E4E4E",
"A 	c #5E5E5E",
"B 	c #CAD2E1",
"C 	c #CED6E6",
"D 	c #CCD3E3",
"E 	c #CCD2E2",
"F 	c #909DBA",
"G 	c #5B6276",
"H 	c #3C3E44",
"I 	c #535353",
"J 	c #626262",
"K 	c #6C7792",
"L 	c #94A1C0",
"M 	c #51619B",
"N 	c #8694B4",
"O 	c #7986A4",
"P 	c #596275",
"Q 	c #36373B",
"R 	c #565656",
"S 	c #474C5B",
"T 	c #485169",
"U 	c #8A95AF",
"V 	c #484B54",
"W 	c #3E434E",
"X 	c #4D5569",
"Y 	c #4D5773",
"Z 	c #353D5E",
"` 	c #757D8D",
" .	c #667086",
"..	c #636E84",
"+.	c #515A72",
"@.	c #3F465A",
"#.	c #57617C",
"$.	c #4E5872",
"%.	c #313746",
"&.	c #959FB0",
"*.	c #32353C",
"=.	c #5A606B",
"-.	c #313132",
";.	c #5F626B",
">.	c #32394E",
",.	c #808CA8",
"'.	c #747E94",
").	c #4A4C51",
"!.	c #707784",
"~.	c #72798B",
"{.	c #3E4457",
"].	c #98A6C1",
"^.	c #8593B3",
"/.	c #7986A8",
"(.	c #616C8B",
"_.	c #55607A",
":.	c #67759A",
"<.	c #5E6A89",
"[.	c #474E60",
"}.	c #8E97AC",
"|.	c #35363D",
"1.	c #505560",
"2.	c #343434",
"3.	c #5A5A5A",
"4.	c #636364",
"5.	c #535966",
"6.	c #475065",
"7.	c #7B86A0",
"8.	c #798397",
"9.	c #696C72",
"0.	c #9CA8BE",
"a.	c #8591A7",
"b.	c #8593AD",
"c.	c #8998BD",
"d.	c #8C9ABC",
"e.	c #55638F",
"f.	c #7380A5",
"g.	c #8290B3",
"h.	c #525E85",
"i.	c #676E7C",
"j.	c #777D8F",
"k.	c #44464D",
"l.	c #4D505C",
"m.	c #3C3B3C",
"n.	c #5C5D5E",
"o.	c #5F5F5F",
"p.	c #3C455E",
"q.	c #7884A0",
"r.	c #5D6373",
"s.	c #616469",
"t.	c #8896B2",
"u.	c #7683A1",
"v.	c #5C677F",
"w.	c #394255",
"x.	c #384261",
"y.	c #323B5B",
"z.	c #596796",
"A.	c #566597",
"B.	c #2E3759",
"C.	c #404249",
"D.	c #5E636F",
"E.	c #6D7076",
"F.	c #464A52",
"G.	c #464646",
"H.	c #616161",
"I.	c #515662",
"J.	c #56617A",
"K.	c #7F8BA8",
"L.	c #A7A8AB",
"M.	c #A5A9B2",
"N.	c #989CA2",
"O.	c #A5A9B3",
"P.	c #ACB2C1",
"Q.	c #A7ADBE",
"R.	c #9498A3",
"S.	c #A8AEC8",
"T.	c #A5ACC6",
"U.	c #9398A7",
"V.	c #8E9299",
"W.	c #4D535E",
"X.	c #93979F",
"Y.	c #4D4D4D",
"Z.	c #646464",
"`.	c #5F6164",
" +	c #444A5B",
".+	c #8592B0",
"++	c #B8C4DE",
"@+	c #B0BBD1",
"#+	c #717584",
"$+	c #919AA7",
"%+	c #272729",
"&+	c #505050",
"*+	c #484B55",
"=+	c #474E5C",
"-+	c #3D4A7C",
";+	c #3C497A",
">+	c #3C487A",
",+	c #3B487A",
"'+	c #3B4879",
")+	c #646F93",
"!+	c #7C7F8F",
"~+	c #777E8E",
"{+	c #242324",
"]+	c #545353",
"^+	c #5C5C5C",
"/+	c #4F4F4F",
"(+	c #4C4C4C",
"_+	c #4A4949",
":+	c #474747",
"<+	c #454545",
"[+	c #444444",
"}+	c #424242",
"|+	c #585C65",
"1+	c #51555F",
"2+	c #6B7184",
"3+	c #2C2C2F",
"4+	c #ABABAB",
"5+	c #D3D3D3",
"6+	c #D2D2D2",
"7+	c #D1D1D1",
"8+	c #D0D0D0",
"9+	c #8E9199",
"0+	c #6F7480",
"a+	c #5A606E",
"b+	c #3A3B3C",
"c+	c #737A8A",
"d+	c #888F9F",
"e+	c #606674",
"f+	c #707B94",
"g+	c #3E424C",
"h+	c #5B5B5C",
"i+	c #CCD0D8",
"j+	c #97A2B9",
"k+	c #7480A1",
"l+	c #66739E",
"m+	c #707C9E",
"n+	c #BAC2D5",
"o+	c #8C9299",
"p+	c #656970",
"q+	c #5B5C5C",
"r+	c #D0D5D8",
"s+	c #5B5D5F",
"t+	c #586278",
"u+	c #586077",
"v+	c #353949",
"w+	c #3C4151",
"x+	c #3F4353",
"y+	c #404455",
"z+	c #3D4152",
"A+	c #9094A0",
"B+	c #CFD7DE",
"C+	c #46494E",
"D+	c #687288",
"E+	c #5E6167",
"F+	c #7E8186",
"G+	c #040506",
"H+	c #292E38",
"I+	c #5F6574",
"J+	c #454444",
"K+	c #5B5B5B",
"L+	c #585858",
"M+	c #9EA0A2",
"N+	c #4F5258",
"O+	c #030304",
"P+	c #484F60",
"Q+	c #5A5D64",
"R+	c #606061",
"S+	c #71798A",
"T+	c #484F5F",
"U+	c #5A6479",
"V+	c #565960",
"W+	c #555555",
"X+	c #666767",
"Y+	c #6E6E6E",
"Z+	c #6F6F6F",
"`+	c #6A6A6A",
" @	c #75787D",
".@	c #727A8E",
"+@	c #5E6679",
"@@	c #545559",
"#@	c #616162",
"$@	c #636469",
"%@	c #60636A",
"&@	c #595B60",
"*@	c #737373",
"=@	c #787878",
"-@	c #797979",
";@	c #767676",
">@	c #6D6D6D",
",@	c #636569",
"'@	c #5F6269",
")@	c #56585B",
"!@	c #575757",
"                                                ",
"                                                ",
"                . + @ #                         ",
"          $ %   & * = - ;             > , '     ",
"          ) ! ~ { ] ^ / ( _ :       < [ } | 1 2 ",
"          3 4 5 6 7 8 9 0 a b c d   e f g h i   ",
"          j k l m n o p q r s t u v w x y z A   ",
"  B C D D D D D D D D D D D D D D E F G H I J   ",
"  K L M M M M M M M M M M M M M M N O P Q R     ",
"  S T U V W X Y Z `  ...+.@.#.$.%.&.*.=.-.i     ",
"  ;.>.,.'.).!.~.{.].^./.(._.:.<.[.}.|.1.2.3.    ",
"  4.5.6.7.8.9.0.a.b.c.d.e.f.g.h.i.j.k.l.m.n.    ",
"    o.p.q.r.s.t.u.v.w.x.y.z.A.B.C.D.E.F.G.H.    ",
"      I.J.K.L.M.N.O.P.Q.R.S.T.U.V.W.X.H Y.Z.    ",
"      `. +.+++++++++++++++++++++@+#+$+%+&+      ",
"        *+=+-+;+;+;+>+,+,+,+,+'+)+!+~+{+]+      ",
"          ^+I /+(+_+:+<+[+[+[+}+|+1+2+3+R       ",
"                4+5+6+7+7+7+7+8+9+0+a+b+i       ",
"                c+d+d+d+d+d+d+d+e+f+g+[+h+      ",
"                i+j+k+l+l+l+l+l+m+n+o+p+q+      ",
"              r+s+t+u+v+w+x+y+z+A+B+C+D+E+      ",
"              F+G+H+I+J+1 K+^+L+M+N+O+P+Q+R+    ",
"              S+T+U+V+W+X+Y+Z+`+ @.@P++@@@#@    ",
"              $@%@&@1 Z.*@=@-@;@>@,@'@)@!@      "};

/* XPM */
static char * monu_xpm[] = {
"24 24 29 1",
" 	c None",
".	c #FFFFFF",
"+	c #F7F7F7",
"@	c #EFEFEF",
"#	c #E7E7E7",
"$	c #DFDFDF",
"%	c #D5D5D5",
"&	c #CCCCCC",
"*	c #C5C5C5",
"=	c #BEBEBE",
"-	c #B4B4B4",
";	c #ADADAD",
">	c #A2A2A2",
",	c #999999",
"'	c #8B8B8B",
")	c #848484",
"!	c #7B7B7B",
"~	c #757575",
"{	c #666666",
"]	c #5A5A5A",
"^	c #525252",
"/	c #494949",
"(	c #404040",
"_	c #3B3B3B",
":	c #333333",
"<	c #202020",
"[	c #191919",
"}	c #101010",
"|	c #000000",
"..%%%%%%%%%%%%%%%%%%%%..",
"........................",
".......................!",
"...........>}..........)",
"..........||||.........)",
"........|||=.|||$......)",
"......^|||....:|||.....)",
"...!!|||!!!!!!!!|||!!..)",
"...||||||||||||||||||..)",
".......................)",
"....|||.)|||.|||.|||...)",
".....||..||..||..)|....)",
".....||..||..||..)|....)",
".....||..||..||..(|....)",
".....||..||..||..||....)",
".....||..||..||..||....)",
".....||..||..||..||....)",
".....||..||..||..||=...)",
"....(||.(||(>||(.||:...)",
".......................)",
"...||||||||||||||||||..)",
".......................)",
".......................&",
".@(((((/______________,."};

/* XPM */
static char * hotel_xpm[] = {
"24 24 111 2",
"  	c None",
". 	c #66777A",
"+ 	c #7FB5BD",
"@ 	c #85BFC8",
"# 	c #7AABB3",
"$ 	c #555D5E",
"% 	c #78B2BB",
"& 	c #73BFCB",
"* 	c #6C949A",
"= 	c #73ADB6",
"- 	c #6F969D",
"; 	c #98BBC1",
"> 	c #ADC8CD",
", 	c #99BDC2",
"' 	c #76B6C0",
") 	c #F4F6F6",
"! 	c #FFFFFF",
"~ 	c #F6F8F8",
"{ 	c #79B8C2",
"] 	c #A5CACF",
"^ 	c #A9CDD3",
"/ 	c #73BECA",
"( 	c #B9D4D9",
"_ 	c #D8EDF0",
": 	c #E2EDEF",
"< 	c #E6F1F3",
"[ 	c #BBD6DA",
"} 	c #97BEC4",
"| 	c #A7CED5",
"1 	c #72BDC9",
"2 	c #73B6C1",
"3 	c #72B9C4",
"4 	c #E0E0E0",
"5 	c #9BBCC2",
"6 	c #74BDC8",
"7 	c #8FC1C9",
"8 	c #79B2BB",
"9 	c #74B7C1",
"0 	c #EFEFEF",
"a 	c #A2C3C8",
"b 	c #B6CFD3",
"c 	c #F4F4F4",
"d 	c #80B9C2",
"e 	c #D5DDDE",
"f 	c #9EC9D0",
"g 	c #82BBC5",
"h 	c #71ABB4",
"i 	c #6FB5C0",
"j 	c #BACED1",
"k 	c #9AB6BB",
"l 	c #E1E4E4",
"m 	c #C5D4D6",
"n 	c #ABC2C5",
"o 	c #787878",
"p 	c #898989",
"q 	c #FCFCFC",
"r 	c #EAEAEA",
"s 	c #D6D8D8",
"t 	c #D7E9EC",
"u 	c #C1D3D6",
"v 	c #B5D0D4",
"w 	c #ACC8CC",
"x 	c #99B4B9",
"y 	c #94C7CF",
"z 	c #75B7C2",
"A 	c #989898",
"B 	c #7F7F7F",
"C 	c #AFC0C3",
"D 	c #79B6BF",
"E 	c #9D9FA0",
"F 	c #000000",
"G 	c #555555",
"H 	c #DEE5E6",
"I 	c #73BAC5",
"J 	c #6F6F6F",
"K 	c #1F1F1F",
"L 	c #BEBEBE",
"M 	c #585858",
"N 	c #B2B2B2",
"O 	c #F7F7F7",
"P 	c #7CBFCA",
"Q 	c #CDD3D3",
"R 	c #AAB6B8",
"S 	c #CAD6D8",
"T 	c #B4C0C2",
"U 	c #ABB7B9",
"V 	c #E3EFF1",
"W 	c #E9F5F7",
"X 	c #E2EEF0",
"Y 	c #7BBFCA",
"Z 	c #DEE0E1",
"` 	c #C6CCCD",
" .	c #C1C7C8",
"..	c #77BBC6",
"+.	c #C6D7DA",
"@.	c #C3DEE2",
"#.	c #A0D3DC",
"$.	c #72BAC6",
"%.	c #82B3BA",
"&.	c #76B3BD",
"*.	c #79BCC7",
"=.	c #84B5BC",
"-.	c #73BCC8",
";.	c #76B0B9",
">.	c #70989E",
",.	c #617275",
"'.	c #7EB4BC",
").	c #81BAC4",
"!.	c #80BAC3",
"~.	c #7CADB5",
"{.	c #535A5C",
". + @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ # $ ",
"% & & & & & & & & & & & & & & & & & & & & & & * ",
"= & & & & & & & & & & & & & & & & & & & & & & - ",
"= & & & & & & & & & & & & & & & ; > > , & & & - ",
"= & & & & & & & & & & & & & & ' ) ! ! ~ { & & - ",
"= & & & & & & & & & & & & & & ] ! ! ! ! ^ & & - ",
"= & & & & & & & & & & & & & / ( _ : < _ [ / & - ",
"= & & & & & & & & & & & & & & & & } | & & & & - ",
"= & 1 2 3 & & & & & & & & & & & & } | & & & & - ",
"= & 2 4 5 6 7 8 & & & & & & & & & } | & & & & - ",
"= & 9 0 a b ! c d & & & & & & & & } | & & & & - ",
"= & 9 0 a e ! ! f g h i & & & & & } | & & & & - ",
"= & 9 0 j k l m n o p q r s t u v w x y z & & - ",
"= & 9 0 A B C D E F G ! ! ! ! ! ! ! ! ! H I & - ",
"= & 9 0 J F K L M F N ! ! ! ! ! ! ! ! ! O P & - ",
"= & 9 0 Q R R S T U V W W W W W W W W W X Y & - ",
"= & 9 0 Z ` ` ` ` ` ` ` ` ` ` ` ` ` ` `  ...& - ",
"= & 9 0 ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! O P & - ",
"= & 9 0 +.| | | | | | | | | | | | | | @.O P & - ",
"= & 9 0 a & & & & & & & & & & & & & & #.O P & - ",
"= & 9 0 a & & & & & & & & & & & & & & #.O P & - ",
"= & $.%.&.& & & & & & & & & & & & & & *.=.-.& - ",
";.& & & & & & & & & & & & & & & & & & & & & & >.",
",.'.).).).).).).!.).).).).).).).).).).).).).~.{."};


/* XPM */
static char * speedtrap_xpm[] = {
"24 24 29 1",
" 	c None",
".	c #DB4E66",
"+	c #D65E70",
"@	c #F20A2E",
"#	c #EE0E32",
"$	c #EA1236",
"%	c #F20E32",
"&	c #EEEAEB",
"*	c #EE0A2E",
"=	c #FCF6F6",
"-	c #FEEEF2",
";	c #FEFEFE",
">	c #DB3E5A",
",	c #020202",
"'	c #DC425A",
")	c #DA5269",
"!	c #F53E5A",
"~	c #F23251",
"{	c #DA465E",
"]	c #EE1235",
"^	c #FEF2F4",
"/	c #060606",
"(	c #767676",
"_	c #EB1636",
":	c #FAFAFA",
"<	c #9E9E9E",
"[	c #EE0E36",
"}	c #EB163A",
"|	c #EE0A32",
"           .+           ",
"           @@           ",
"          #@@$          ",
"          @@@@          ",
"         %@@@@$         ",
"        &**#@**         ",
"        #**=-@@$        ",
"        ***;;@@@        ",
"       >@@;;;;@@.       ",
"       @*#;,,;#*@       ",
"      '*@;;,,;;@*)      ",
"      @@!;;,,;;~*@      ",
"     {**;;;,,;;;@*)     ",
"     @@*;;;,,;;;@@@     ",
"    ]**^;;;,,;;;^**$    ",
"    @*@;;;;,,;;;;***    ",
"   #@@^;;;;,,;;;;-@@_   ",
"   **@;;;;;;;;;;;;***   ",
"  [@@^;;;;;,,:;;;;-**}  ",
"  ***;;;;;;,,;;;;;;@*@  ",
" @@@;;;;;;;;;;;;;;;;*@* ",
" @@********@**@*@****** ",
"@@@@@*******************",
"|**********************@"};


/* XPM */
static char * girls_xpm[] = {
"24 24 33 1",
" 	c None",
".	c #060404",
"+	c #2C3224",
"@	c #4A5F49",
"#	c #667A56",
"$	c #A6AC9C",
"%	c #ECE2C3",
"&	c #A78651",
"*	c #372210",
"=	c #BEAE76",
"-	c #6E6044",
";	c #C78540",
">	c #DAC99F",
",	c #593919",
"'	c #241F15",
")	c #C1995F",
"!	c #C6AE6A",
"~	c #93612B",
"{	c #F0C27B",
"]	c #1E0F06",
"^	c #DC9346",
"/	c #424C40",
"(	c #E4B780",
"_	c #12130B",
":	c #6A5030",
"<	c #EEB15D",
"[	c #CFA05D",
"}	c #E6B670",
"|	c #F5C792",
"1	c #B66A22",
"2	c #93723B",
"3	c #DEA14E",
"4	c #150B07",
"                        ",
"            #/@         ",
"           $_..+        ",
"          +*,'..+       ",
"         /'[}}~4./      ",
"         +-}||}:..      ",
"         *))|}}2..      ",
"         :{[|);;..@     ",
"         2|{{{};..+     ",
"         >{<<{{~4._     ",
"          (1^<[*...     ",
"          ><<^~....     ",
"           }^;,..._#    ",
"          %}3;,]...     ",
"        >((}3:^~4.4     ",
"       >)[(}:3^;:._     ",
"      %&:{[':<3<^*]     ",
"      (*&)']3<<<<,.     ",
"     %24='.,}<<<3,.     ",
"     =''-..,<<<<^,.     ",
"    >/..4..2<<<33*4     ",
"    &.....'3<<<3[]/     ",
"   >^_..._~<}<<<!$      ",
"   [;,...*^<<<3(%       "};

/* XPM */
static char * airport_xpm[] = {
"24 24 152 2",
"  	c None",
". 	c #BCBCBC",
"+ 	c #919191",
"@ 	c #909090",
"# 	c #959595",
"$ 	c #C8C8C8",
"% 	c #D0D2D0",
"& 	c #657665",
"* 	c #122F12",
"= 	c #0F2C0F",
"- 	c #0E2C0E",
"; 	c #183518",
"> 	c #7C8A7C",
", 	c #DBDCDB",
"' 	c #B0B0B0",
") 	c #536053",
"! 	c #208820",
"~ 	c #01B101",
"{ 	c #00B300",
"] 	c #01B301",
"^ 	c #04AE04",
"/ 	c #287D28",
"( 	c #616661",
"_ 	c #C3C3C3",
": 	c #132613",
"< 	c #009500",
"[ 	c #00FA00",
"} 	c #00FF00",
"| 	c #00FE00",
"1 	c #01FE01",
"2 	c #01ED01",
"3 	c #01BC01",
"4 	c #00C500",
"5 	c #00F300",
"6 	c #00FD00",
"7 	c #00F100",
"8 	c #007900",
"9 	c #232B23",
"0 	c #ABABAB",
"a 	c #132713",
"b 	c #01D001",
"c 	c #025002",
"d 	c #016801",
"e 	c #00E200",
"f 	c #142714",
"g 	c #01CC01",
"h 	c #023E02",
"i 	c #015801",
"j 	c #00E000",
"k 	c #019501",
"l 	c #01F901",
"m 	c #01E201",
"n 	c #01A801",
"o 	c #023402",
"p 	c #014901",
"q 	c #00BA00",
"r 	c #00E600",
"s 	c #00FB00",
"t 	c #01FD01",
"u 	c #01FB01",
"v 	c #01E901",
"w 	c #018401",
"x 	c #023002",
"y 	c #020F02",
"z 	c #021502",
"A 	c #013901",
"B 	c #009900",
"C 	c #00F200",
"D 	c #00FC00",
"E 	c #01DC01",
"F 	c #01A001",
"G 	c #019101",
"H 	c #023902",
"I 	c #030403",
"J 	c #030303",
"K 	c #020202",
"L 	c #020702",
"M 	c #008B00",
"N 	c #009100",
"O 	c #00A900",
"P 	c #00E700",
"Q 	c #01F401",
"R 	c #01E801",
"S 	c #019F01",
"T 	c #022C02",
"U 	c #020E02",
"V 	c #030703",
"W 	c #020802",
"X 	c #013F01",
"Y 	c #00B400",
"Z 	c #00EB00",
"` 	c #00EE00",
" .	c #00DB00",
"..	c #017C01",
"+.	c #023602",
"@.	c #020D02",
"#.	c #020302",
"$.	c #021302",
"%.	c #013E01",
"&.	c #008F00",
"*.	c #00DD00",
"=.	c #008400",
"-.	c #014701",
";.	c #011701",
">.	c #012001",
",.	c #014E01",
"'.	c #015901",
").	c #009600",
"!.	c #00E100",
"~.	c #00F500",
"{.	c #00EC00",
"].	c #015001",
"^.	c #00CC00",
"/.	c #00EF00",
"(.	c #00F900",
"_.	c #00F700",
":.	c #00D600",
"<.	c #012F01",
"[.	c #014201",
"}.	c #00EA00",
"|.	c #007F00",
"1.	c #012A01",
"2.	c #021702",
"3.	c #013201",
"4.	c #00F400",
"5.	c #008800",
"6.	c #008600",
"7.	c #00C100",
"8.	c #00F800",
"9.	c #A3A3A3",
"0.	c #3A4A3A",
"a.	c #138D13",
"b.	c #00CD00",
"c.	c #00D000",
"d.	c #00CF00",
"e.	c #00CB00",
"f.	c #02C802",
"g.	c #197B19",
"h.	c #494F49",
"i.	c #BABABA",
"j.	c #E4E4E4",
"k.	c #BBBFBB",
"l.	c #557555",
"m.	c #073D07",
"n.	c #043A04",
"o.	c #0E410E",
"p.	c #6B846B",
"q.	c #C7C9C7",
"r.	c #AAAAAA",
"s.	c #727272",
"t.	c #707070",
"u.	c #777777",
"                                                ",
"    . + @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ # $     ",
"  % & * = = = = = = = = - - - - - - - - ; > ,   ",
"' ) ! ~ { { { ] ] ] ] ] { { { { { { { { ^ / ( _ ",
"@ : < [ } } | | 1 1 2 3 4 5 6 6 6 6 6 6 7 8 9 0 ",
"@ a < [ } } | | 1 1 b c d e 6 6 6 6 6 6 7 8 9 0 ",
"@ f < [ } } | | 1 1 g h i j 6 6 6 6 6 6 7 8 9 0 ",
"@ f < [ } } | | 1 1 g h i j 6 6 6 6 6 6 7 8 9 0 ",
"@ f < [ | | | | 1 1 g h i j 6 6 6 6 6 6 7 8 9 0 ",
"@ f k l 1 1 1 1 1 1 g h i j 6 6 6 6 6 6 7 8 9 0 ",
"@ f k l 1 1 1 1 l m n o p q r s 6 6 6 6 7 8 9 0 ",
"@ f k l t t u u v w x y z A B C [ s D 6 7 8 9 0 ",
"@ f k l t E F G w H I J K L p M N O P 6 7 8 9 0 ",
"@ f k Q R S T y U V J J K K W U U X Y Z ` 8 9 0 ",
"@ a k  ...+.@.#.#.#.K K K K K K K $.%.&.j 8 9 0 ",
"@ : < *.=.i i i i i -.;.>.,.i i i i '.).!.8 9 0 ",
"@ : < ~.{.r r r r r q A ].^.r r r r r /./.8 9 0 ",
"@ : < (.6 6 6 6 6 6 ^.%.i j 6 6 6 6 6 6 7 8 9 0 ",
"@ : < (.6 6 6 6 _.:.B <.[.O *.[ 6 6 6 6 7 8 9 0 ",
"@ : < (.6 6 6 6 }.|.1.$.2.3.< 4.6 6 6 6 7 8 9 0 ",
"@ : < (.6 6 6 6 C Y 5.6.6.M 7.8.6 6 6 6 7 8 9 0 ",
"9.0.a.b.c.c.c.c.d.b.e.e.e.e.b.c.c.c.c.c.f.g.h.i.",
"j.k.l.m.n.n.n.n.n.n.n.n.n.n.n.n.n.n.n.n.o.p.q.  ",
"    r.s.t.t.t.t.t.t.t.t.t.t.t.t.t.t.t.t.u.i.    "};


/* XPM */
static char * golf_xpm[] = {
"24 24 9 1",
" 	c None",
".	c #E20404",
"+	c #CBB399",
"@	c #FFFFFF",
"#	c #000000",
"$	c #D8C6B2",
"%	c #00FF00",
"&	c #577900",
"*	c #459400",
"                        ",
"          ...           ",
"          .++@@@@@@@@@  ",
"          .@@@@###@@@@  ",
"          @@@@@#@#@@@@  ",
"          @@@@@###@@@@  ",
"          @@@@@@@#@@@@  ",
"          @@@@@###@@@@  ",
"          .$$@@@@@@@@@  ",
"          ...           ",
"          ...           ",
"          ...           ",
"          @@@           ",
"          @@@           ",
"          @@@           ",
"     %%%%&@@@%%%%%%     ",
"   %%%%%%&...%%%%%%%%   ",
"  %%%%%%%&...%%%%%%%%%  ",
" %%%%%%%%&...%%%%%%%%%% ",
" %%%%%%%%*...%%%%%%%%%% ",
" %%%%%%%%%%%%%%%%%%%%%  ",
"   %%%%%%%%%%%%%%%%%%   ",
"     %%%%%%%%%%%%%%     ",
"          %%%%          "};


/* XPM */
static char * fuel_xpm[] = {
"24 24 10 1",
" 	c None",
".	c #000000",
"+	c #3F3F3F",
"@	c #7F7F7F",
"#	c #262626",
"$	c #FFFFFF",
"%	c #4C4C4C",
"&	c #727272",
"*	c #E5E5E5",
"=	c #444444",
"                        ",
"                        ",
"                        ",
"                        ",
"                        ",
"                        ",
"                        ",
"          .....         ",
"         .......        ",
"         ........       ",
"         ..+@@#...      ",
"         ..@$$%....     ",
"         ..&**=.. .     ",
"         ........  ..   ",
"         ........  ..   ",
"         ........  ..   ",
"         ........    .  ",
"         ........    .  ",
"         ........    .  ",
"         ........    .  ",
"         ........    .  ",
"         ............   ",
"                        ",
"                        "};

/* XPM */
static char * cafe_xpm[] = {
"24 24 260 2",
"  	c None",
". 	c #010000",
"+ 	c #070506",
"@ 	c #0A0907",
"# 	c #030000",
"$ 	c #161211",
"% 	c #080405",
"& 	c #090806",
"* 	c #080403",
"= 	c #FFFDFD",
"- 	c #F9F3F3",
"; 	c #FFF9FA",
"> 	c #FFFCFD",
", 	c #ECE2E3",
"' 	c #FFFBFD",
") 	c #F5EBEC",
"! 	c #010002",
"~ 	c #040500",
"{ 	c #12110D",
"] 	c #F4EFEC",
"^ 	c #FFFDFB",
"/ 	c #FFFCFB",
"( 	c #FFFBFB",
"_ 	c #FFEFF0",
": 	c #FEEBED",
"< 	c #FFF9FB",
"[ 	c #FFEDF0",
"} 	c #FEEEF1",
"| 	c #FEF8FA",
"1 	c #F0EEF1",
"2 	c #020003",
"3 	c #080609",
"4 	c #030104",
"5 	c #FEFCFF",
"6 	c #000000",
"7 	c #FAF6F3",
"8 	c #FAF2F0",
"9 	c #D8CACA",
"0 	c #CEBEBF",
"a 	c #F6E2E4",
"b 	c #FAE4E7",
"c 	c #F6DBE0",
"d 	c #E7CACF",
"e 	c #FDE0E5",
"f 	c #F3DCE2",
"g 	c #CEC5C8",
"h 	c #E4E2E5",
"i 	c #FFFEFF",
"j 	c #EAE8EB",
"k 	c #B6B4B7",
"l 	c #DBD9DC",
"m 	c #CCC0C0",
"n 	c #CCBCBD",
"o 	c #A89496",
"p 	c #5B4548",
"q 	c #482D32",
"r 	c #52353A",
"s 	c #5E3D44",
"t 	c #5E3B42",
"u 	c #4A252D",
"v 	c #4F3139",
"w 	c #DBD0D4",
"x 	c #BCBABD",
"y 	c #C5C3C6",
"z 	c #545255",
"A 	c #9C9A9D",
"B 	c #F3E7E7",
"C 	c #DECECF",
"D 	c #5C494B",
"E 	c #4B3538",
"F 	c #2A1115",
"G 	c #2F1217",
"H 	c #2F1016",
"I 	c #2F0C13",
"J 	c #361119",
"K 	c #370F18",
"L 	c #41222A",
"M 	c #54484C",
"N 	c #89878A",
"O 	c #C7C5C8",
"P 	c #918F92",
"Q 	c #FFFAFD",
"R 	c #B4A1A5",
"S 	c #442D33",
"T 	c #361D23",
"U 	c #3A1C24",
"V 	c #2F1018",
"W 	c #290811",
"X 	c #36121C",
"Y 	c #2F0B15",
"Z 	c #25070F",
"` 	c #B8ADB1",
" .	c #F8F6F9",
"..	c #BDBBBE",
"+.	c #060407",
"@.	c #E1DFE2",
"#.	c #0B090C",
"$.	c #0B0004",
"%.	c #F4E5EA",
"&.	c #FFF6F9",
"*.	c #FFF9FF",
"=.	c #FFF2F7",
"-.	c #FFF2FA",
";.	c #FFEFF5",
">.	c #FFEFF8",
",.	c #FFF5FD",
"'.	c #FFF5FF",
").	c #FFECF4",
"!.	c #FFFCFF",
"~.	c #F4F2F5",
"{.	c #1A181B",
"].	c #211F22",
"^.	c #F7F5F8",
"/.	c #C4C2C5",
"(.	c #110B0F",
"_.	c #D6D0D2",
":.	c #FFFBFF",
"<.	c #FFF8FE",
"[.	c #FFF5F9",
"}.	c #FFF0F8",
"|.	c #FEEBF1",
"1.	c #FFF7FF",
"2.	c #FFFAFF",
"3.	c #E5DFE3",
"4.	c #ADABAE",
"5.	c #A5A3A6",
"6.	c #E9E7EA",
"7.	c #E6E4E7",
"8.	c #171518",
"9.	c #F2EDF1",
"0.	c #D0CBCF",
"a.	c #FAF5F9",
"b.	c #E9E3E7",
"c.	c #DAD4D8",
"d.	c #E3DADF",
"e.	c #D6CDD2",
"f.	c #C1B8BD",
"g.	c #C6BDC2",
"h.	c #BFB6BB",
"i.	c #AFAAAE",
"j.	c #CAC8CB",
"k.	c #959396",
"l.	c #0A080B",
"m.	c #000004",
"n.	c #F9FAFE",
"o.	c #FEFFFF",
"p.	c #F7F8FC",
"q.	c #E2E3E7",
"r.	c #C9CACE",
"s.	c #D6D7DB",
"t.	c #D5D6DA",
"u.	c #C6C7CB",
"v.	c #B1B0B5",
"w.	c #A4A2A5",
"x.	c #AAA8AB",
"y.	c #A6A4A7",
"z.	c #09070A",
"A.	c #4D4E52",
"B.	c #DFE3E6",
"C.	c #E0E4E7",
"D.	c #D1D5D8",
"E.	c #D4D8DB",
"F.	c #C2C6C9",
"G.	c #B1B5B8",
"H.	c #BDC1C4",
"I.	c #ADAEB0",
"J.	c #ABABAD",
"K.	c #A2A0A3",
"L.	c #7F7D80",
"M.	c #0C0A0D",
"N.	c #010103",
"O.	c #D3D3D5",
"P.	c #EDEDEF",
"Q.	c #FDFDFF",
"R.	c #525254",
"S.	c #FFFFFF",
"T.	c #DCDCDE",
"U.	c #D7D7D9",
"V.	c #DFDFE1",
"W.	c #DDDDDF",
"X.	c #C2C2C4",
"Y.	c #CBCBCD",
"Z.	c #ACACAE",
"`.	c #B8B8BA",
" +	c #B3B3B5",
".+	c #848484",
"++	c #3A3A3A",
"@+	c #C9C9C9",
"#+	c #C6C6C6",
"$+	c #FDFBFE",
"%+	c #EBE9EC",
"&+	c #F5F3F6",
"*+	c #F1EFF2",
"=+	c #FFFDFF",
"-+	c #CECCCF",
";+	c #C3C1C4",
">+	c #ABA9AC",
",+	c #9B9B9B",
"'+	c #5F5F5F",
")+	c #4A4A4A",
"!+	c #999999",
"~+	c #D2D2D2",
"{+	c #E3E3E3",
"]+	c #F3F3F3",
"^+	c #040205",
"/+	c #E3E1E4",
"(+	c #FCFAFD",
"_+	c #5D5B5E",
":+	c #D1CFD2",
"<+	c #E8E6E9",
"[+	c #DFDDE0",
"}+	c #C0BEC1",
"|+	c #B2B0B3",
"1+	c #A9A7AA",
"2+	c #8E8E8E",
"3+	c #404040",
"4+	c #939393",
"5+	c #C3C3C3",
"6+	c #F4F4F4",
"7+	c #FBFBFB",
"8+	c #CCCCCC",
"9+	c #0A0A0A",
"0+	c #EEECEF",
"a+	c #FBF9FC",
"b+	c #E5E3E6",
"c+	c #5C5A5D",
"d+	c #5E5C5F",
"e+	c #565457",
"f+	c #3B393C",
"g+	c #424043",
"h+	c #4F4D50",
"i+	c #383639",
"j+	c #9D9D9D",
"k+	c #F0F0F0",
"l+	c #F9F9F9",
"m+	c #FCFCFC",
"n+	c #C7C7C7",
"o+	c #110F12",
"p+	c #C1BFC2",
"q+	c #DAD8DB",
"r+	c #D4D2D5",
"s+	c #F8F8F8",
"t+	c #DBDBDB",
"u+	c #BCBCBC",
"v+	c #D8D6D9",
"w+	c #EDEBEE",
"x+	c #F3F1F4",
"y+	c #F2F0F3",
"z+	c #F1F1F1",
"A+	c #E1E1E1",
"B+	c #121013",
"C+	c #B8B6B9",
"D+	c #D2D0D3",
"E+	c #B4B2B5",
"F+	c #B9B7BA",
"G+	c #949295",
"H+	c #0B0B0B",
"I+	c #0D0B0E",
"J+	c #252326",
"K+	c #242225",
"                                                ",
"                                                ",
"                                                ",
"                                                ",
"                  . + @ # $ % #                 ",
"              & * = - ; > , ' ) % !             ",
"          ~ { ] ^ / ( _ : < [ } | 1 2   3 ! 4 5 ",
"        6 7 8 / 9 0 a b c d e f g h i 6 j k l 6 ",
"        # ^ m n o p q r s t u v w x y i z ! A 6 ",
"        # B C D E F G H I J K L M N O i ! i P 6 ",
"        # ' Q R S T U V W X Y Z ` i  ...! +.@.#.",
"        $.' %.&.*.=.-.;.>.,.'.).!.~.i {.].^./.! ",
"        (._.!.:.<.[.*.*.}.|.1.2.3.4.5.! 6.7.!   ",
"          8.9.0.a.b.c.d.e.f.g.h.i.j.k.! l.6     ",
"          m.n.o.p.q.r.s.t.u.u.v.w.x.y.z.        ",
"      # m.A.q.p.B.C.D.E.F.G.H.I.J.K.L.M.! i     ",
"  N.# O.P.Q.R.S.T.U.V.W.X.Y.Z.`. +.+++@+#+# 6   ",
"z.$+%+1 &+*+6 1 =+i -+;+k >+..>+,+'+)+!+~+{+]+6 ",
"^+i j  ./+%+(+_+7.:+<+[+}+|+k 1+2+3+4+5+6+7+8+9+",
"M.K.<+(+0+a+b+i 6 c+d+e+f+g+h+i+6 j+S.k+l+m+n+6 ",
"  o+p+}+i  .[+^.i q+@.i (+r+i (+S.7+S.s+t+u+6   ",
"    ! #.# v+w+x+ .i y+x+i =+x+ .z+S.A+# # 6     ",
"          l.3 B+5.C+D+E+>+F+G+|+6 H+6           ",
"                I+! ! J+4 o+K+! S.]+            "};


/* XPM */
static char * kismet_xpm[] = {
"36 20 101 2",
"  	c None",
". 	c #C7C8EA",
"+ 	c #C4C5E9",
"@ 	c #C6C7EA",
"# 	c #C5C6EA",
"$ 	c #C3C4E9",
"% 	c #C8C9EB",
"& 	c #C9CAEB",
"* 	c #C4C5EA",
"= 	c #C7C8EB",
"- 	c #B8B8E4",
"; 	c #A1A1DB",
"> 	c #B8B9E4",
", 	c #BCBDE6",
"' 	c #BEBFE7",
") 	c #BDBEE7",
"! 	c #413DB3",
"~ 	c #231FA7",
"{ 	c #2D2AAB",
"] 	c #3835B0",
"^ 	c #4743B6",
"/ 	c #2A26AA",
"( 	c #2420A7",
"_ 	c #2623A9",
": 	c #8E8ED3",
"< 	c #B9B9E5",
"[ 	c #2925AA",
"} 	c #2420A8",
"| 	c #7674C9",
"1 	c #4946B7",
"2 	c #2320A8",
"3 	c #4C49B8",
"4 	c #514EB9",
"5 	c #504DB9",
"6 	c #504CB9",
"7 	c #2825A9",
"8 	c #4D4AB8",
"9 	c #322FAD",
"0 	c #8180CE",
"a 	c #6361C2",
"b 	c #2926AA",
"c 	c #5D5CBF",
"d 	c #3632AF",
"e 	c #514DB9",
"f 	c #231FA8",
"g 	c #4E4BB9",
"h 	c #2F2CAC",
"i 	c #3A37B1",
"j 	c #413EB3",
"k 	c #332FAD",
"l 	c #2521A8",
"m 	c #4643B5",
"n 	c #4A47B7",
"o 	c #9E9EDA",
"p 	c #B9BAE5",
"q 	c #2824A9",
"r 	c #3F3CB3",
"s 	c #2C28AB",
"t 	c #6966C3",
"u 	c #4946B6",
"v 	c #413EB4",
"w 	c #2D29AB",
"x 	c #5856BD",
"y 	c #2C29AB",
"z 	c #9B9BD9",
"A 	c #3D3AB2",
"B 	c #322EAD",
"C 	c #3834B0",
"D 	c #4D49B8",
"E 	c #514EBA",
"F 	c #3B38B1",
"G 	c #7876CA",
"H 	c #6D6CC6",
"I 	c #5250BB",
"J 	c #524FBB",
"K 	c #2622A8",
"L 	c #4C48B7",
"M 	c #3C39B1",
"N 	c #4542B5",
"O 	c #4945B6",
"P 	c #4743B5",
"Q 	c #4E4BB8",
"R 	c #8685D0",
"S 	c #4340B4",
"T 	c #5D5BBF",
"U 	c #6765C3",
"V 	c #5552BB",
"W 	c #4F4CB9",
"X 	c #312DAD",
"Y 	c #4D4BB8",
"Z 	c #2B27AB",
"` 	c #615FC1",
" .	c #4643B6",
"..	c #716FC7",
"+.	c #BABBE5",
"@.	c #A9A9DE",
"#.	c #B3B3E2",
"$.	c #BABAE5",
"%.	c #B8B9E5",
"&.	c #B7B8E4",
"*.	c #C9C9EB",
"                            . . + + @ @                                 ",
"                        # $ $ $ $ $ $ $ $ +                             ",
"                    % $ $ $ # . . . @ $ $ $ $ &                         ",
"                    + $ * = # $ $ $ + . # $ $ @                         ",
"                      # @ $ $ $ $ $ $ $ # @ *                           ",
"                      % $ $ $ + . # $ $ $ @                             ",
"                        - ; > @ $ + , > ' )                             ",
"! ~   { ]     ^ ~       / ( _ : $ < [ } | 1 2 3     4 ~ ~ 5   6 ~ ~ ~ 7 ",
"! ~ 1 ~ 8     ^ ~     9 } 0 } a $ < b } c d ~ 8     e f g       h ~ i   ",
"j } k l       ^ ~     m 2 n o p $ < [ q r s q 8     5 ~ t         ~ u   ",
"v ~ ~ w       ^ ~       x ( y z = p [ A l B C D     E ~ ~         2 1   ",
"! ~ F ~       ^ ~       G H } I   p [ J K L M 8     E ~           ~ 1   ",
"j ~ N ~ O     P ~     Q ~ R [ S     b T B U M 8     5 ~ V         ~ 1   ",
"! ~ W q X     m ~       h l l Y     Z `  ...i 3     E ~ ~ ~       ~ u   ",
"                      # +.o @.      #.$.%., &.                          ",
"                      $ $ $           + $ $ *                           ",
"                    + $ $ %           *.$ $ $ @                         ",
"                    % $ $ #           @ $ $ $ &                         ",
"                        # $ $ # % . # $ $ +                             ",
"                            . . + + @ @                                 "};

/* XPM */
static char *geocache_xpm[]={
"24 24 6 1",
"  c None",
"a c #00c000",
"b c #303030",
"c c #58a8ff",
". c #c0c000",
"d c #ff0000",
"...........  aaaaaaaaaaa",
"..........bbbbaaaaaaaaaa",
"........bb.  abbaaaaaaaa",
"......bb...  aaabbaaaaaa",
"......bb...  aaabbaaaaaa",
"......b.bb.  abbabaaaaaa",
"......b...bbbbaaabaaaaaa",
"......b....  aaaabaaaaaa",
"......b....  aaaabaaaaaa",
"......b....  aaaabaaaaaa",
"......b....  aaaabaaaaaa",
"      b          b      ",
"      b          b      ",
"ccccccbcccc  ddddbdddddd",
"ccccccbcccc  ddddbdddddd",
"ccccccbcccc  ddddbdddddd",
"ccccccbcccc  ddddbdddddd",
"ccccccbcccc  ddddbdddddd",
"ccccccbcccc  ddddbdddddd",
"ccccccbbccc  dddbbdddddd",
"ccccccccbbc  dbbdddddddd",
"ccccccccccbbbbdddddddddd",
"ccccccccccc  ddddddddddd",
"ccccccccccc  ddddddddddd"};
